DelaySampler

Struct DelaySampler 

pub struct DelaySampler<S>
where S: DurationSampler,
{ /* private fields */ }
A sampler that delays the output of a base sampler by adding the value from a delay sampler.

If the delay sampler returns a negative value, it is treated as zero, meaning the delay is not applied. If you need to support negative values (e.g., to accelerate the schedule), use JitterSampler instead.

Implementations

Source

impl<S> DelaySampler<S>
where S: DurationSampler,

pub fn new(sampler: S, delay_sampler: Box<dyn DurationSampler>) -> Self

Creates a new DelaySampler.