pub struct EnsureNonNegativeSampler<S, F>{ /* private fields */ }Expand description
A sampler that ensures the sampled duration is non-negative.
It attempts to sample from the base sampler up to limit_try_count times.
If all attempts return a negative value, it falls back to the result of the
fallback closure.
Implementations