pub struct DelaySampler<S>where
S: DurationSampler,{ /* private fields */ }Expand description
A sampler that delays the output of a base sampler by adding the value from a delay sampler.
If the delay sampler returns a negative value, it is treated as zero, meaning the delay is not applied. If you need to support negative values (e.g., to accelerate the schedule), use JitterSampler instead.
Implementations
Sourceimpl<S> DelaySampler<S>where
S: DurationSampler,
impl<S> DelaySampler<S>where
S: DurationSampler,
Sourcepub fn new(sampler: S, delay_sampler: Box<dyn DurationSampler>) -> Self
pub fn new(sampler: S, delay_sampler: Box<dyn DurationSampler>) -> Self
Creates a new DelaySampler.